@@ -1,6 +1,6 @@
 package Pcore::App::Redis;
 
-use Pcore qw[-cli -class];
+use Pcore qw[-class];
 
 extends qw[Pcore::App::Alien];
 
@@ -15,17 +15,17 @@ our $CFG = {
     }
 };
 
-sub _build_redis_ver {
-    my $self = shift;
+# CLI
+sub cli_name ($self) {
+    return 'redis';
+}
 
-    return $self->cfg->{REDIS}->{REDIS_VER} || $DIST->{REDIS}->{REDIS_VER};
+sub _build_redis_ver ($self) {
+    return $self->cfg->{REDIS}->{REDIS_VER} || $PROC->{CFG}->{REDIS}->{REDIS_VER};
 }
 
 # APP
-around _build_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _build_cfg => sub ( $orig, $self ) {
     return P->hash->merge(
         $self->$orig,
         $CFG,
@@ -61,10 +61,7 @@ around _build_cfg => sub {
     );
 };
 
-around _create_local_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {
         REDIS => {
             REDIS_VER => $self->cfg->{REDIS}->{REDIS_VER},
@@ -77,15 +74,11 @@ around _create_local_cfg => sub {
     return P->hash->merge( $self->$orig, $local_cfg );
 };
 
-sub _build_alien_dir {
-    my $self = shift;
-
+sub _build_alien_dir ($self) {
     return $self->app_dir . 'redis-' . $self->redis_ver . q[/];
 }
 
-sub _build_alien_data_dir {
-    my $self = shift;
-
+sub _build_alien_data_dir ($self) {
     my $dir = $self->app_dir . 'redis-data/';
 
     P->file->mkpath($dir);
@@ -93,22 +86,15 @@ sub _build_alien_data_dir {
     return $dir;
 }
 
-sub _build_alien_bin_path {
-    my $self = shift;
-
+sub _build_alien_bin_path ($self) {
     return $self->alien_dir . 'src/redis-server';
 }
 
-sub _build_alien_cfg_path {
-    my $self = shift;
-
+sub _build_alien_cfg_path ($self) {
     return $self->app_dir . 'redis.conf';
 }
 
-around app_build => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_build => sub ( $orig, $self ) {
     $self->$orig;
 
     if ( -d $self->alien_dir ) {
@@ -144,18 +130,13 @@ around app_build => sub {
     return;
 };
 
-around app_deploy => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_deploy => sub ( $orig, $self ) {
     $self->$orig;
 
     return;
 };
 
-sub generate_alien_cfg {
-    my $self = shift;
-
+sub generate_alien_cfg ($self) {
     my $cfg;
 
     my $add_key = sub {
@@ -192,15 +173,11 @@ sub generate_alien_cfg {
     return;
 }
 
-sub master_proc {
-    my $self = shift;
-
+sub master_proc ($self) {
     return;
 }
 
-sub alien_proc {
-    my $self = shift;
-
+sub alien_proc ($self) {
     $self->generate_alien_cfg;
 
     exec $self->alien_bin_path, $self->alien_dir . 'redis.conf', q[--include ] . $self->alien_cfg_path or die;
@@ -212,4 +189,18 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::App::Redis
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 ATTRIBUTES
+
+=head1 METHODS
+
+=head1 SEE ALSO
+
 =cut
